Learn R Programming

orf (version 0.1.4)

check_honesty_fraction: check honesty fraction

Description

Checks the input data of honesty.fraction in orf

Usage

check_honesty_fraction(honesty.fraction, honesty)

Value

honesty.fraction

Arguments

honesty.fraction

scalar, share of the data set aside to estimate the effects (default is 0.5)

honesty

logical, if data should be split into train and honest sample