Learn R Programming

orf (version 0.1.4)

honest_split: honest sample split

Description

Creates honest sample split by randomly selecting prespecified share of observations to belong to honest sample and to training sample

Usage

honest_split(data, honesty.fraction, orf)

Value

named list of honest and training sample

Arguments

data

dataframe or matrix of features and outcomes to be split honestly

honesty.fraction

share of sample to belong to honesty sample

orf

logical, if honest split should be done for orf or not