Learn R Programming

orf (version 0.1.4)

summary.orf.prediction: Summary of the Ordered Forest Prediction

Description

summary of Ordered Forest predictions of class orf.prediction

Usage

# S3 method for orf.prediction
summary(object, latex = FALSE, ...)

Arguments

object

predicted Ordered Forest object of class orf.prediction

latex

logical, if TRUE latex coded summary will be generated (default is FALSE)

...

further arguments (currently ignored)

Author

Gabriel Okasa

Details

summary.orf.prediction provides a main summary of the Ordered Forest prediction, including the input information regarding the values of hyperparameters as well as the inputs of the predict.orf function.

Examples

Run this code
# Ordered Forest
require(orf)

# load example data
data(odata)

# specify response and covariates for train and test
idx <- sample(seq(1, nrow(odata), 1), 0.8*nrow(odata))

# train set
Y_train <- as.numeric(odata[idx, 1])
X_train <- as.matrix(odata[idx, -1])

# test set
Y_test <- as.numeric(odata[-idx, 1])
X_test <- as.matrix(odata[-idx, -1])

# estimate Ordered Forest
orf_fit <- orf(X_train, Y_train)

# predict the probabilities with the estimated orf
orf_pred <- predict(orf_fit, newdata = X_test)

# summary of the prediction object
summary(orf_pred)

# show summary of the orf prediction coded in LaTeX
summary(orf_pred, latex = TRUE)

Run the code above in your browser using DataLab